/*
 * sw-ui-bootstrap
 * AngularJS directives for Bootstrap

 * Created By: Michelle Darlea <mdarlea@gmail.com> (https://github.com/mdarlea)
 * https://github.com/mdarlea/sw-ui-bootstrap

 * Version: 1.0.3 - 2015-07-16
 * License: ISC
 */
angular.module('sw.ui.bootstrap', ['sw.ui.bootstrap.tpls', 'sw.ui.bootstrap.form']);
angular.module('sw.ui.bootstrap.tpls', ['template/form/field-date.html','template/form/field-text.html','template/form/form-field.html']);
(function () {
    'use strict';
    
    /**
    * @ngdoc overview
    * @name sw.ui.bootstrap.form
 
    * @description This module contains form controls
    * - {@link sw.ui.bootstrap.form.directive:swFormField swFormField} directive    
    */
    angular.module('sw.ui.bootstrap.form', ['ui.bootstrap']);
    
    /**
    * @ngdoc directive
    * @name sw.ui.bootstrap.form.directive:swFormField
    * @element ANY
    * @restrict EA
    * @require ngModel
    * @scope    
    * @function 
    *
    * @description
    * Renders a form field. The following field types are supported: text, date
    *
    * @param {string} label The form field label
    * @param {string} [type='text'] The field type. Acceptable values: 'text', 'date'
    * @param {string} [placeholder=''] The field watermark
    * @param {boolean} [inline=false] 
    *   If true then the 'form-inline' css bootstrap class is used. 
    *   If false then the 'form-group' css class is used    * 
    * @param {ngModel} ngModel The {@link ng.directive:ngModel ngModel} directive attached to the associated input field
    * @param {Object} options Additional field options 
    * @param {string} [options.formatYear='yy'] Available for date field type.
    * @param {Number} [options.startingDay=1] Available for date field type. 
    * @param {datetime} [options.minDate] The minimum date allowed in the date-time picker
    * @param {boolean} [options.required=false] True if the field is required, False otherwise
    * 
    * @example
    <example module="sw.ui.bootstrap">
     <file name="index.html">         
        <sw-form-field label="Birth Date:" 
                       placeholder="Birth Date" 
                       type="date" 
                       data-ng-model="birthDate">
        </sw-form-field>
     </file>
    </example>
    */
    angular.module('sw.ui.bootstrap.form')
        .controller("FormController", ["$scope", function ($scope) {
            function getTemplate(type) {
                var name = (type) ? type : "text";
                return ("template/form/field-" + name + ".html");
            }
            
            function isDate(type) {
                return type === "date";
            }
            
            function updateFieldOptions(type, options) {
                if (isDate(type)) {
                    var defaultDateOptions = {
                        formatYear: 'yy', 
                        startingDay: 1,
                        minDate: new Date()
                    };
                    $scope.dateOptions = $.extend(true, {}, defaultDateOptions, options);
                } else {
                    $scope.dateOptions = null;
                }
                $.extend(true, $scope.fieldOptions, options);
            }
            
            $scope.fieldOptions = {
                required: false
            };
            
            $scope.$watch('type', function (type) {
                $scope.template = getTemplate(type);
                updateFieldOptions(type, $scope.options);
            });
            
            $scope.$watch('options', function (newVal, oldVal) {
                updateFieldOptions($scope.type, newVal);
            }, true);
            
            $scope.open = function ($event) {
                $event.preventDefault();
                $event.stopPropagation();
                
                $scope.opened = true;
            };
        }])
        .directive('swFormField', [function () {
            return {
                restrict: 'EA',
                require: '?ngModel',
                scope: {
                    label: '@',
                    type: '@',
                    placeholder: '@',
                    title: '@',
                    inline: '@',
                    options: '=',
                    ngModel: '='
                },
                controller: 'FormController',
                templateUrl: 'template/form/form-field.html'
            };
        }]);
})();
angular.module("template/form/field-date.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/form/field-date.html",
    "<div class=\"input-group\">\n" +
    "    <input type=\"text\"\n" +
    "           class=\"form-control\"\n" +
    "           placeholder=\"{{$parent.placeholder}}\"\n" +
    "           datepicker-popup=\"{{$parent.fieldOptions.format}}\"\n" +
    "           data-ng-model=\"$parent.ngModel\"\n" +
    "           is-open=\"$parent.opened\"\n" +
    "           min-date=\"$parent.fieldOptions.minDate\"\n" +
    "           max-date=\"$parent.fieldOptions.maxDate\"\n" +
    "           datepicker-options=\"$parent.dateOptions\"\n" +
    "           date-disabled=\"$parent.disabled(date, mode)\"\n" +
    "           ng-required=\"{{$parent.fieldOptions.required}}\"\n" +
    "           close-text=\"Close\" />\n" +
    "    <span class=\"input-group-btn\">\n" +
    "        <button type=\"button\"\n" +
    "                class=\"btn btn-default\"\n" +
    "                ng-click=\"$parent.open($event)\">\n" +
    "            <i class=\"glyphicon glyphicon-calendar\"></i>\n" +
    "        </button>\n" +
    "    </span>\n" +
    "</div>\n" +
    "\n" +
    "");
}]);

angular.module("template/form/field-text.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/form/field-text.html",
    "<input type=\"text\"\n" +
    "       class=\"form-control\"\n" +
    "       required=\"{{$parent.fieldOptions.required}}\"\n" +
    "       data-ng-model=\"$parent.ngModel\"\n" +
    "       title=\"{{$parent.title}}\"\n" +
    "       placeholder=\"{{$parent.placeholder}}\" />\n" +
    "");
}]);

angular.module("template/form/form-field.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/form/form-field.html",
    "<div ng-class=\"{'form-inline':inline,'form-group':!inline}\">\n" +
    "    <label class=\"control-label\" ng-if=\"label\">{{label}}</label>\n" +
    "\n" +
    "    <span data-ng-include=\"template\"></span>\n" +
    "   \n" +
    "    <span class=\"help-block\"></span>\n" +
    "</div>\n" +
    "");
}]);
